/* _dict.cc 03/05/1998 00.27.50 */
/* mod_rarp.cc 28/08/2000 18.13.32 */
PUBLIC MODULE_rarp::MODULE_rarp (void);
PUBLIC void MODULE_rarp::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_rarp::domenu (MENU_CONTEXT context, const char *key);
PUBLIC int MODULE_rarp::dohtml (const char *key);
PUBLIC int MODULE_rarp::probe (int level, int , bool);
PUBLIC int MODULE_rarp::execmain (int argc, char *argv[], bool);
/* rarp.cc 07/08/2000 00.40.58 */
PUBLIC RARP_ENTRY::RARP_ENTRY (const char *str, int noline);
PUBLIC RARP_ENTRY::RARP_ENTRY (const char *_ip,
	 const char *_hw,
	 int _active,
	 const char *_comment);
PUBLIC RARP_ENTRY::RARP_ENTRY (void);
PUBLIC int RARP_ENTRY::set (void);
PUBLIC int RARP_ENTRY::cmp (const char *ipstr);
PUBLIC int RARP_ENTRY::unset (void);
PUBLIC RARP_ENTRY *RARP_ENTRIES::getitem (int no);
PUBLIC RARP_ENTRY *RARP_ENTRIES::locate (const char *ipstr);
PUBLIC RARP_ENTRIES::RARP_ENTRIES (void);
PUBLIC int RARP_ENTRIES::write (void);
PUBLIC RARP_ENTRIES::RARP_ENTRIES (CONFIG_FILE&f);
PUBLIC void RARP_ENTRIES::update (RARP_ENTRIES&current);
PRIVATE int RARP_ENTRY::normalise (void);
PUBLIC int RARP_ENTRY::is_valid (int talk);
PUBLIC int RARP_ENTRY::edit (void);
PUBLIC int RARP_ENTRIES::edit (void);
PUBLIC int RARP_ENTRIES::isoneactive (void);
